@@ -1,3 +1,5 @@
+use std::fmt;
+
 #[derive(Debug, PartialEq, Eq)]
 pub enum Operation {
     Division,
@@ -15,11 +17,20 @@ pub enum Expression {
 }
 
 #[derive(Debug, PartialEq, Eq)]
-
 pub enum ExpressionErrors {
     UnexpectedElement(String),
 }
 
+impl fmt::Display for ExpressionErrors {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        match self {
+            ExpressionErrors::UnexpectedElement(message) => {
+                write!(f, "{}", message)
+            }
+        }
+    }
+}
+
 impl Expression {
     pub fn execute(&self) -> f64 {
         match self {
